Package: buzzMed
Version: 0.1.2
Date: 2026-05-20
Title: Bayesian Understanding for Mediator Selection Framework
Authors@R: c(
    person("Dingjing", "Shi", email = "dshi32@gatech.edu", role = c("aut", "cre")),
    person("Tansu", "Celikel", role = "aut"),
    person("Dexin", "Shi", role = "aut"),
    person("Chih-Chia", "Hsing", email = "jesscc.hsing@gmail.com", role = "ctb")
    )
Description: A collection of quantitative tools for selecting mediating effects within exploratory Bayesian mediation models. The package accommodates both continuous and dichotomous outcomes, including the dependent variables and the mediators for identifying and analyzing mediation pathways.
License: GPL (>= 3)
Depends: R (>= 4.0.0)
SystemRequirements: JAGS (>= 4.0.0)
Imports: coda, methods, rjags, stats, utils
Suggests: knitr, rmarkdown, spelling, testthat (>= 3.0.0)
ByteCompile: true
VignetteBuilder: knitr
URL: https://github.com/olfactorybulb/buzzMed
BugReports: https://github.com/olfactorybulb/buzzMed/issues
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-21 01:46:21 UTC; jesshsing
Author: Dingjing Shi [aut, cre],
  Tansu Celikel [aut],
  Dexin Shi [aut],
  Chih-Chia Hsing [ctb]
Maintainer: Dingjing Shi <dshi32@gatech.edu>
Repository: CRAN
Date/Publication: 2026-05-28 11:20:06 UTC
Built: R 4.6.0; ; 2026-05-28 13:23:13 UTC; unix
