# Generated by roxygen2: do not edit by hand

export(buzzEBMcatMcatY)
export(buzzEBMcatMcontY)
export(buzzEBMcontMcatY)
export(buzzEBMcontMcontY)
export(longBMed)
export(run_parms_wizard)
importFrom(coda,as.mcmc.list)
importFrom(methods,setClass)
importFrom(rjags,coda.samples)
importFrom(rjags,jags.model)
importFrom(stats,rnorm)
importFrom(stats,setNames)
importFrom(stats,update)
importFrom(utils,head)
