% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{sublongspikes}
\alias{sublongspikes}
\title{A subset in time of longitudinal spike train data.}
\format{
A numeric array with dimensions 300 × 25 × 21:
\describe{
  \item{Dimension 1 (N)}{300 observations.}
  \item{Dimension 2 (T)}{25 repeated measurements (time points).}
  \item{Dimension 3 (Variables)}{21 variables consisting of one predictor
  (X), 19 candidate mediators (M), and one outcome (Y).}
}
}
\source{
Longitudinal spiking train data included with the \pkg{buzzMed} package.
}
\usage{
data(sublongspikes)
}
\description{
For each neuron across all repetitions, the time series that describe
whether or not a neuron generated action potential is provided. This
is a subset of the full data matrix where the temporal index starts
at 1002 ms and continues until 1026 ms.
}
\details{
The third dimension stores the variables in the following order:
\enumerate{
  \item Slice 1: Predictor (X)
  \item Slices 2--20: Candidate mediators (M)
  \item Slice 21: Outcome (Y)
}
}
\keyword{datasets}
