% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{framing2}
\alias{framing2}
\title{Modified framing dataset with some dichotomization}
\format{
A data frame with 265 observations and 10 variables:
\describe{
  \item{tone}{From the original \code{framing} dataset.
  First treatment; whether the news story is framed positively or negatively. }

  \item{eth}{From the original \code{framing} dataset.
  Second treatment; whether the news story features a Latino or European immigrant.}

  \item{treat}{From the original \code{framing} dataset.
  Product of the two treatment variables. In the original study the authors
  only find this cell to be significant.}

  \item{negemo2}{Recoded from the \code{emo} variable in the original
  \code{framing} dataset. Binary variable of subjects' negative feelings
  during the experiment. A value of 1 indicates an original score of 3--7,
  corresponding to stronger negative emotions, whereas a value of 0 indicates
  an original score of 8--12.}

  \item{p_harm2}{Recoded from the \code{p_harm} variable in the original
  \code{framing} dataset. Binary variable of subjects' perceived harm
  caused by increased immigration.  A value of 1 indicates an original
  score of 6--8, whereas a value of 0 indicates a score of 2--5.}

  \item{att2}{Recoded from the \code{immigr} variable in the original
  \code{framing} dataset. Binary variable measuring subjects' attitudes
  toward increased immigration. A value of 1 indicates an original score
  of 3 or 4, corresponding to more negative attitudes toward increased
  immigration. A value of 0 indicates an original score of 1 or 2.}

  \item{anx2}{Recoded from the \code{anx} variable in the original
  \code{framing} dataset. Binary variable measuring subjects' anxiety
  about increased immigration. A value of 1 indicates respondents who
  reported being ``very anxious'' or ``somewhat anxious'' about increased
  immigration. A value of 0 indicates respondents who reported being
  ``a little anxious'' or ``not anxious at all''.}

  \item{english2}{Recoded from the \code{english} variable in the original
  \code{framing} dataset. Binary variable measuring support for making
  English the official language of the United States. A value of 1 indicates
  respondents who selected ``Favor'' or ``Strongly Favor''.
  A value of 0 indicates respondents who selected ``Oppose''
  or ``Strongly Oppose''.}

  \item{congmsg}{From the original \code{cong_mesg} variable in
  the \code{framing} dataset. Whether subjects requested sending an
  anti-immigration message to Congress on their behalf.}

  \item{info}{From the original \code{anti_info} variable in the
  \code{framing} dataset. Whether subjects wanted to receive
  information from anti-immigration organizations.}
}
}
\source{
Adapted from the \code{framing} dataset in the \pkg{mediation} package.
}
\usage{
framing2
}
\description{
A modified version of the \code{framing} dataset from the
\pkg{mediation} package, originally based on the study by
Brader, Valentino, and Suhay (2008). The candidate mediators have been
dichotomized relative to the original \code{framing} dataset. The dataset
contains 265 observations and 10 variables.
}
\references{
Brader, T., Valentino, N. A., & Suhay, E. (2008).
What Triggers Public Opposition to Immigration? Anxiety, Group Cues,
and Immigration Threat.
\emph{American Journal of Political Science}, 52(4), 959--978.
}
\keyword{datasets}
